@@ -29,29 +29,48 @@ class Population(object):
             self._curr_gen[i].gen_id = gen_id
             self._curr_gen[i].idv_id = i
 
+    def __str__(self) -> str:
+        rlt_str = f"population({self._size:d}/{self._capacity}):\n"
+        rlt_str += f"current generation @{self._gen_id:d}:\n"
+        for p in self._curr_gen:
+            rlt_str += f"{p}\n"
+        rlt_str += f"parents [{len(self._parents):d}]:\n"
+        for p in self._parents:
+            rlt_str += f"{p}\n"
+        rlt_str += f"children [{len(self._children):d}]:\n"
+        for p in self._children:
+            rlt_str += f"{p}\n"
+        rlt_str += f"next generation [{len(self._next_gen):d}]:\n"
+        for p in self._next_gen:
+            rlt_str += f"{p}\n"
+        return rlt_str
+
+    def __format__(self, format_spec: str) -> str:
+        return str(self)
+
     @property
-    def gen_id(self):
+    def gen_id(self) -> int:
         return self._gen_id
 
     @property
-    def curr_gen(self):
+    def curr_gen(self) -> List[Individual]:
         return self._curr_gen.copy()
 
     @property
-    def parents(self):
+    def parents(self) -> List[Individual]:
         if not self._parents:
             raise ValueError('parents not avialable, need select() in prior.')
         return self._parents.copy()
 
     @property
-    def children(self):
+    def children(self) -> List[Individual]:
         if not self._children:
             raise ValueError(
                 'children not available, need reproduce() in prior.')
         return self._children.copy()
 
     @property
-    def next_gen(self):
+    def next_gen(self) -> List[Individual]:
         if not self._next_gen:
             raise ValueError(
                 'next generation not available, need elimate() in prior.')
@@ -64,7 +83,7 @@ class Population(object):
                 person.express()
                 person.evaluate()
 
-    def size(self):
+    def size(self) -> int:
         return self._size
 
     def append_newcomer(self, newcomer: Individual):
@@ -115,7 +134,7 @@ class Population(object):
                 'invalid cross_prob. Must in [0,1], got %6.4f' % cross_prob)
         self._children = []
         n_parents = len(self._parents)
-        for i in range(n_parents):
+        for _ in range(n_parents):
             if np.random.uniform(0, 1) < cross_prob:
                 # select parents
                 p0_idx = np.random.randint(0, n_parents)
@@ -160,4 +179,4 @@ class Population(object):
         survivors = self.eliminate()
         next_gen_id = self._gen_id + 1
         next_population = Population(next_gen_id, survivors, self._capacity)
-        return next_population
\ No newline at end of file
+        return next_population
