@@ -28,8 +28,7 @@ class TestPopulation(unittest.TestCase):
         chm = self.ancestor.plasm
         print('\nancestor: %s' % self.ancestor)
         for i in range(10):
-            chm.random()
-            p = Individual(chm)
+            p = Individual(chm.random())
             p._fitness = i * 2
             p_list.append(p)
         self.people_test = Population(3, p_list, capacity=10)
@@ -61,6 +60,11 @@ class TestPopulation(unittest.TestCase):
         with self.assertRaises(ValueError):
             self.people_0.next_gen
 
+    def test_str(self):
+        print(self.people_0)
+        print(self.people_1)
+        print(self.people_test)
+
     def test_evaluate(self):
         with self.assertRaises(NotImplementedError):
             Population.evaluate(self.people_1.curr_gen)
@@ -87,7 +91,7 @@ class TestPopulation(unittest.TestCase):
         print('selected parents:')
         for i in self.people_test.parents:
             print(i)
-
+        print(self.people_test)
         self.people_test.select(3)
         print('selected parenet:')
         for i in self.people_test.parents:
@@ -101,11 +105,12 @@ class TestPopulation(unittest.TestCase):
         for p in parent:
             print(p)
         children = self.people_test.reproduce()
+        print(self.people_test)
         print('children:')
         for c in children:
             print(c)
         self.assertTrue(0 < len(children) <= self.people_test.size())
-    
+
     def test_eliminate(self):
         print(f'\ncurrent generation:')
         for p in self.people_test.curr_gen:
@@ -124,7 +129,8 @@ class TestPopulation(unittest.TestCase):
         print('next generation:')
         for p in next_generation:
             print(p)
-        self.assertEqual(next_generation[0].gen_id, self.people_test.gen_id + 1)
+        self.assertEqual(
+            next_generation[0].gen_id, self.people_test.gen_id + 1)
         self.assertTrue(next_generation[0].is_growup())
 
     def test_evolve(self):
@@ -133,13 +139,15 @@ class TestPopulation(unittest.TestCase):
             print(p)
         Individual.express = express
         Individual.evaluate = evaluate
+        last_gen_id = self.people_test.gen_id
         next_generation = self.people_test.evolve()
+        curr_gen_id = next_generation.gen_id
+        self.assertEqual(last_gen_id + 1, curr_gen_id)
         del self.people_test
         print('next generation:')
         for p in next_generation.curr_gen:
             print(p)
 
 
-
 if __name__ == "__main__":
     unittest.main()
